@@ -5,13 +5,13 @@
 
     Murphy's style from CodeRay.
 
-    :copyright: 2006-2007 by Georg Brandl.
-    :license: BSD, see LICENSE for more details.
+    :copyright: Copyright 2006-2010 by the Pygments team, see AUTHORS.
+    :license: BSD, see LICENSE for details.
 """
 
 from pygments.style import Style
 from pygments.token import Keyword, Name, Comment, String, Error, \
-     Number, Operator, Generic
+     Number, Operator, Generic, Whitespace
 
 
 class MurphyStyle(Style):
@@ -22,6 +22,7 @@ class MurphyStyle(Style):
     default_style = ""
 
     styles = {
+        Whitespace:                "#bbbbbb",
         Comment:                   "#666 italic",
         Comment.Preproc:           "#579 noitalic",
         Comment.Special:           "#c00 bold",
